==> haskell-double-conversion-2.0.2.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-double-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 double-conversion
version:              2.0.2.0
visibility:           public
id:                   double-conversion-2.0.2.0-6ZzEfG2PMID82lsCUFfxTz
key:                  double-conversion-2.0.2.0-6ZzEfG2PMID82lsCUFfxTz
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/double-conversion
synopsis:
    Fast conversion between double precision floating point and text

description:
    A library that performs fast, accurate conversion between double
    precision floating point and text.

    This library is implemented as bindings to the C++
    @double-conversion@ library written by Florian Loitsch at Google:
    <https://github.com/floitsch/double-conversion>.

    The '\''Text'\'' versions of these functions are about 30 times faster
    than the default '\''show'\'' implementation for the '\''Double'\'' type.

    The '\''ByteString'\'' versions are /slower/ than the '\''Text'\'' versions;
    roughly half the speed.  (This seems to be due to the cost of
    allocating '\''ByteString'\'' values via @malloc@.)

    As a final note, be aware that the @bytestring-show@ package is
    about 50% slower than simply using '\''show'\''.

category:             Text
abi:                  aacf5f63996b17cbae0fadcc3784c5a5
exposed:              True
exposed-modules:
    Data.Double.Conversion.ByteString Data.Double.Conversion.Text

hidden-modules:       Data.Double.Conversion.FFI
import-dirs:          /usr/lib/ghc-8.10.2/site-local/double-conversion-2.0.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/double-conversion-2.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/double-conversion-2.0.2.0

hs-libraries:         HSdouble-conversion-2.0.2.0-6ZzEfG2PMID82lsCUFfxTz
extra-libraries:      stdc++ double-conversion
depends:
    base-4.14.1.0 bytestring-0.10.10.0 ghc-prim-0.6.1 text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-double-conversion/html/double-conversion.haddock

haddock-html:         /usr/share/doc/haskell-double-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-double-conversion-2.0.2.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-double-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 double-conversion
version:              2.0.2.0
visibility:           public
id:                   double-conversion-2.0.2.0-4bYN6LLzdsTAgyEjepTqx2
key:                  double-conversion-2.0.2.0-4bYN6LLzdsTAgyEjepTqx2
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/double-conversion
synopsis:
    Fast conversion between double precision floating point and text

description:
    A library that performs fast, accurate conversion between double
    precision floating point and text.

    This library is implemented as bindings to the C++
    @double-conversion@ library written by Florian Loitsch at Google:
    <https://github.com/floitsch/double-conversion>.

    The '\''Text'\'' versions of these functions are about 30 times faster
    than the default '\''show'\'' implementation for the '\''Double'\'' type.

    The '\''ByteString'\'' versions are /slower/ than the '\''Text'\'' versions;
    roughly half the speed.  (This seems to be due to the cost of
    allocating '\''ByteString'\'' values via @malloc@.)

    As a final note, be aware that the @bytestring-show@ package is
    about 50% slower than simply using '\''show'\''.

category:             Text
abi:                  5a486c866e3925b17a500706bccb8931
exposed:              True
exposed-modules:
    Data.Double.Conversion.ByteString Data.Double.Conversion.Text

hidden-modules:       Data.Double.Conversion.FFI
import-dirs:          /usr/lib/ghc-8.10.2/site-local/double-conversion-2.0.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/double-conversion-2.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/double-conversion-2.0.2.0

hs-libraries:         HSdouble-conversion-2.0.2.0-4bYN6LLzdsTAgyEjepTqx2
extra-libraries:      stdc++ double-conversion
depends:
    base-4.14.1.0 bytestring-0.10.10.0 ghc-prim-0.6.1 text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-double-conversion/html/double-conversion.haddock

haddock-html:         /usr/share/doc/haskell-double-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
